@@ -1,23 +1,14 @@
-/* ============================================================
- *
- * This file is part of the KDE project
- *
- * Date        : 2007-09-13
- * Description : Sane interface for KDE
- *
+/*
  * SPDX-FileCopyrightText: 2007-2010 Kare Sars <kare dot sars at iki dot fi>
  * SPDX-FileCopyrightText: 2009 Grzegorz Kurtyka <grzegorz dot kurtyka at gmail dot com>
  * SPDX-FileCopyrightText: 2014 Gregor Mitsch : port to KDE5 frameworks
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
- *
- * ============================================================ */
+ */
 
 #ifndef KSANE_DEVICE_DIALOG_H
 #define KSANE_DEVICE_DIALOG_H
 
-#include "ksanecore.h"
-
 #include <QGroupBox>
 #include <QStringList>
 #include <QButtonGroup>
@@ -28,6 +19,8 @@
 #include <QBoxLayout>
 #include <QDialog>
 
+#include <KSaneCore/Interface>
+
 namespace KSaneIface
 {
 
@@ -43,11 +36,11 @@ public:
     void setDefault(const QString &);
 
 public Q_SLOTS:
-    void updateDevicesList(const QList<KSaneCore::DeviceInfo> &list);
+    void updateDevicesList(const QList<KSaneCore::DeviceInformation*> &list);
     void reloadDevicesList();
-    
+
 Q_SIGNALS:
-    void requestReloadList();
+    void requestReloadList(const KSaneCore::Interface::DeviceType type);
 
 private Q_SLOTS:
     void setAvailable(bool avail);
