@@ -1,10 +1,8 @@
-/* ============================================================
- *
+/*
  * SPDX-FileCopyrightText: 2007-2011 Kare Sars <kare.sars@iki .fi>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
- *
- * ============================================================ */
+ */
 
 #ifndef LABELED_GAMMA_H
 #define LABELED_GAMMA_H
@@ -37,12 +35,13 @@ public:
      * \param max is the maximum gamma-table-value
      */
     LabeledGamma(QWidget *parent, const QString &text, int max);
-    
-    LabeledGamma(QWidget *parent, KSaneOption *option, QColor color = Qt::black);
+
+    LabeledGamma(QWidget *parent, KSaneCore::Option *option, QColor color = Qt::black);
+
     ~LabeledGamma() override;
 
     void setColor(const QColor &color);
-    
+
     int maxValue();
 
     bool getValues(int &brightness, int &contrast, int &gamma);
@@ -55,10 +54,10 @@ Q_SIGNALS:
 
 private Q_SLOTS:
     void emitNewValues();
-    
+
 private:
     void initGamma(QString text, int max);
-    
+
     LabeledSlider *m_brightSlider;
     LabeledSlider *m_contrastSlider;
     LabeledSlider *m_gammaSlider;
@@ -67,7 +66,7 @@ private:
     int     m_contrast = 0;
     int     m_gamma = 0;
     int     m_maxValue;
-    
+
     GammaDisp  *m_gammaDisplay;
 };
 
